@@ -12,7 +12,6 @@
 import os
 import posixpath
 import sys
-from typing import TYPE_CHECKING
 
 from docutils import nodes
 from docutils.writers.html5_polyglot import HTMLTranslator as BaseTranslator
@@ -23,7 +22,8 @@ from sphinx.locale import admonitionlabels, _
 from sphinx.util import logging
 from sphinx.util.images import get_image_size
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any  # NOQA
     from sphinx.builders.html import StandaloneHTMLBuilder  # NOQA
 
@@ -827,7 +827,7 @@ class HTML5Translator(BaseTranslator):
         # type: (nodes.Node, unicode) -> None
         logger.warning('using "math" markup without a Sphinx math extension '
                        'active, please use one of the math extensions '
-                       'described at http://sphinx-doc.org/ext/math.html',
+                       'described at http://sphinx-doc.org/en/master/ext/math.html',
                        location=(self.builder.current_docname, node.line))
         raise nodes.SkipNode
 
